"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PrefixFactory = void 0;
const MethodFactory_1 = require("./MethodFactory");
const defaults = {
    level: (opts) => `[${opts.level}]`,
    name: (opts) => opts.logger.name,
    template: '{{time}} {{level}} ',
    time: () => new Date().toTimeString().split(' ')[0]
};
class PrefixFactory extends MethodFactory_1.MethodFactory {
    constructor(logger, options) {
        super(logger);
        this.options = Object.assign({}, defaults, options);
    }
    interpolate(level) {
        return this.options.template.replace(/{{([^{}]*)}}/g, (stache, prop) => {
            const fn = this.options[prop];
            if (typeof fn === 'function') {
                return fn({ level, logger: this.logger });
            }
            return stache;
        });
    }
    make(methodName) {
        const og = super.make(methodName);
        return (...args) => {
            const output = this.interpolate(methodName);
            const [first] = args;
            if (typeof first === 'string') {
                args[0] = output + first;
            }
            else {
                args.unshift(output);
            }
            og(...args);
        };
    }
}
exports.PrefixFactory = PrefixFactory;
//# sourceMappingURL=PrefixFactory.js.map